function LL = computeLLOfGraph(graph, communities)
% computes the LL taking the outside density and attributing overlapping
% edges to those communities that come first

% upper triangulars only
explainedEdges = sparse(length(graph),length(graph));
coverGraph = sparse(length(graph),length(graph));

triuGraph = triu(graph);

%inside part
observed1sInside = nan(length(communities),1);
expectedAreaInside = nan(length(communities),1);
for i = 1:length(communities)
    fprintf('.');
    comm = communities(i); 
    observed1sInside(i) = nnz(triuGraph(comm.members, comm.members) & comm.model & ~explainedEdges(comm.members,comm.members));
    expectedAreaInside(i) = nnz(triu(comm.model)) - nnz(coverGraph(comm.members,comm.members) & comm.model);
    coverGraph(comm.members,comm.members) = coverGraph(comm.members,comm.members) | triu(comm.model);
    explainedEdges(comm.members,comm.members) = explainedEdges(comm.members,comm.members) ...
                                                    | (triuGraph(comm.members,comm.members) & comm.model);
end
observed0sInside = expectedAreaInside - observed1sInside;
expect1observe1 = sum(logMult(observed1sInside,observed1sInside./expectedAreaInside));
expect1observe0 = sum(logMult(observed0sInside,observed0sInside./expectedAreaInside));

%outside part
totalExpectedAreaOutside = getAreaOfTriu(length(graph)) - sum(expectedAreaInside);
totalObserved1sOutside = nnz(triuGraph) - sum(observed1sInside);
totalObserved0sOutside = totalExpectedAreaOutside - totalObserved1sOutside;
expect0observe1 = logMult(totalObserved1sOutside,totalObserved1sOutside/totalExpectedAreaOutside);
expect0observe0 = logMult(totalObserved0sOutside,totalObserved0sOutside/totalExpectedAreaOutside);

LL =  expect1observe1 + expect1observe0 + expect0observe1 + expect0observe0;
fprintf('\n');
end
