function result = getCommunityStatisticsForMultipleCommunities(graph, communities)
% takes multiple communities into account, upper triangular only
% The node ids of the described communities have to comply to the ordering 
% of the provided graph and must be provided in their respective degree 
% order. The parameter 'communities' is expected to be a struct array with 
% fields 'members' and 'model'.

% expected area
rows = [];
columns = [];
for c=communities
    [I, J] = find(c.model);
    rows = [rows c.members(I)];
    columns = [columns c.members(J)];
end
coverGraph = sparse(rows, columns, 1, length(graph), length(graph));
triuCoverGraph = triu(coverGraph);
triuGraph = triu(graph);
expectedAreaInside = nnz(triuCoverGraph);
expectedAreaOutside = getAreaOfTriu(length(graph)) - expectedAreaInside;
observed1sInside = nnz(triuGraph & triuCoverGraph);
observed1sOutside = nnz(triuGraph) - observed1sInside;

result = [observed1sInside, observed1sOutside, ...
          expectedAreaInside, expectedAreaOutside];
end

