#include <omp.h>
#include <inttypes.h>
#include "mex.h"
#include <simstruc.h> // needed to forward printf output to matlab

/* Returns the number of elements inside a community described by N, H, and
 * gamma.
 *
 * This function is intended to be called from Matlab.
 */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]) {
    if (nrhs != 3)
        mexErrMsgTxt("Wrong number of input arguments. Exactly three arguments expected.");
    if (nlhs != 1)
        mexErrMsgTxt("Wrong number of output arguments. Exactly one argument expected.");

    const int64_t N = (int64_t) mxGetScalar(prhs[0]);
    double* Hs = (double*) mxGetPr(prhs[1]);
    double* gammas = (double*) mxGetPr(prhs[2]);
    const int numParamCombis = (int) mxGetNumberOfElements (prhs[1]);

    plhs[0] = mxCreateNumericArray (
        mxGetNumberOfDimensions (prhs[1]), mxGetDimensions(prhs[1]), 
        mxGetClassID(prhs[1]), mxREAL);
    double* area = mxGetPr (plhs[0]);

#pragma omp parallel for
    for (int paramCombi = 0; paramCombi < numParamCombis; ++paramCombi) {
        const int64_t H = (int64_t) Hs[paramCombi];
        const int64_t gamma = (int64_t) gammas[paramCombi];

        area[paramCombi] = (H+1)*N-(H+1)-((H+1)*(H+1)-(H+1))/2;

        for (int64_t i = H+1; i < gamma; i++) {
            // derived from maxIndex = floor(theta/(i+p)-p) for integer division
            const int64_t gamma2NH = gamma*gamma-(N-1)*H;
            const int64_t NH2gamma = N-1+H - 2*gamma;
            const int64_t iNHgamma = i*NH2gamma+gamma2NH;
            const int64_t maxIndex = ((gamma-H)*(gamma-H)*(gamma-(N-1))*(gamma-(N-1))-gamma2NH*iNHgamma) / (NH2gamma*iNHgamma);
            area[paramCombi] = area[paramCombi] + maxIndex - i;
        }
    }
    
    return;
}