function [ comm, X, vecComm ] = readCommunities( pathToDataSet, pathToCommunities, numberOfHeaderLines, minSize, maxSize, X)
%READCOMMUNITIES Returns a list of communities described in the specified
%files.
%   The first parameter has to be the name of the file that conatins the
%   undirected graph. It has to contain a line for each edge specifying the
%   source and destination node ID. The second parameter has to be the name
%   of the file that contains ground truth communities: Each line in that
%   file enumerates the nodes that belong to one community.
%
%   The first file may have a header of arbitrary length. The number of
%   lines to ignore, if any, has to be specified in the third parameter.
%
%   Optionally, the minimum and maximum community size can be specified,
%   and the graph will only be parsed again if it is not provided in X.
if (~exist('numberOfHeaderLines', 'var'))
    numberOfHeaderLines = 0;
end
if (~exist('minSize', 'var'))
    minSize = 0;
end
if (~exist('maxSize', 'var'))
    maxSize = Inf;
end
comm = {};
vecComm = {};

if (~exist('X', 'var'))
    edges = dlmread(pathToDataSet, '', numberOfHeaderLines, 0); 
    rows = edges(:,1);
    indexFix = 1-min(rows);
    rows = rows+indexFix;
    cols = edges(:,2)+indexFix;
    val = ones(length(edges),1);
    X = sparse([rows; cols],[cols; rows],[val; val]);
else
    indexFix = 0;
    if ~isempty(strfind(pathToDataSet,'dblp'))
        indexFix =1;
    end
end

try
    fid = fopen(pathToCommunities);
    tline = fgets(fid);
    c=1;
    while ischar(tline)
        vec = sscanf(tline, '%f');
        vec = vec+indexFix;
        if length(vec) > minSize && length(vec) < maxSize
            block = X(vec,:);
            comm{c} = block(:,vec);
            vecComm{c} = vec;
            c=c+1;
        end
        tline = fgets(fid);
    end
catch e
    disp('Could not write the communities because:');
    disp(e.message);
    disp('Min of last vector was:');
    disp(min(vec));
    disp('Index fix was');
    disp(indexFix);
end

