% extends communities from the core
minsize = 100; 
maxsize = 1000; 
if ~exist('communities', 'var')
    try load(['../data/youtube_' int2str(minsize) '_' int2str(maxsize) '.mat']);
    catch
        dataset = '../data/com-youtube.ungraph.txt';
        communityInfo = '../data/com-youtube.all.cmty.txt';
        skiplines = 4;
        [communities, graph, commVec] = readCommunities(...
            dataset, communityInfo, skiplines, minsize, maxsize);
        % small ones first
        [order,indices] = sort(cellfun('length', commVec), 'ascend');
        communities=communities(indices);
        commVec = commVec(indices);
        save(['../data/youtube_' int2str(minsize) '_' int2str(maxsize) '.mat'],...
            'graph', 'commVec', 'communities');
    end
end
trials = 1000;
triangles = nan(trials,3);
parfor i = 1:trials
    t = getTriangle(graph);
    fprintf('Start with (%i -- %i -- %i):\n', t);
    [ comm, LL, p1, p2 ] = growCommunity(t, graph, 'H,gamma', maxsize);
    
    jacc = zeros(length(commVec),1);
    cont = zeros(length(commVec),1);
    for k=1:length(commVec)
        [~,indexOrder]=degree_ord(communities{k}); %#ok<PFBNS>
        ci = commVec{k}(indexOrder);
        jacc(k) = jaccard(comm,ci);
        cont(k) = containment(comm,ci);
    end
    [bestJaccard, commWithBestJaccard] = max(jacc); 
    [bestContainment, commWithBestContainment] = max(cont); 
    taskID = getCurrentTask(); 
    try tmp = load(['results_communitiesFromTriangles' int2str(taskID.ID) '.mat']);
        results = tmp.results;
    catch
        results = cell(0,9);
    end
    results(end+1,:) = { t, comm, LL, p1, p2, bestJaccard, bestContainment,...
                         commWithBestJaccard, commWithBestContainment };
    parsave(['results_communitiesFromTriangles' int2str(taskID.ID) '.mat'], results);
    triangles(i,:) = t;
end
